==> farms_1.2.0.zip: farms/doc/farms.R <==
###################################################
### chunk number 1: 
###################################################
#line 45 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp8G5tU5/R.INSTALL59c95e32/farms/inst/doc/farms.Rnw"
options(width=75)
set.seed(0)
library(farms)
library(utils)
farmsVer<-packageDescription("farms")$Version


###################################################
### chunk number 2: 
###################################################
#line 122 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp8G5tU5/R.INSTALL59c95e32/farms/inst/doc/farms.Rnw"
library(farms)
library(affydata)


###################################################
### chunk number 3: 
###################################################
#line 199 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp8G5tU5/R.INSTALL59c95e32/farms/inst/doc/farms.Rnw"
data(Dilution)
eset<-qFarms(Dilution)  
INIs <- INIcalls(eset)  # apply I/NI calls
summary(INIs)   
I_data <- getI_Eset(INIs) # affybatch containing only  informative probe sets
I_data 


###################################################
### chunk number 4: 
###################################################
#line 210 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp8G5tU5/R.INSTALL59c95e32/farms/inst/doc/farms.Rnw"
  plot(INIs)  # draws a density plot of I/NI-calls


###################################################
### chunk number 5: 
###################################################
#line 221 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp8G5tU5/R.INSTALL59c95e32/farms/inst/doc/farms.Rnw"
eset<-qFarms(Dilution, laplacian=TRUE)  
INIs <- INIcalls(eset)  # apply I/NI calls
summary(INIs)   
I_data <- getI_Eset(INIs) # affybatch containing only  informative probe sets
I_data 


###################################################
### chunk number 6: 
###################################################
#line 231 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp8G5tU5/R.INSTALL59c95e32/farms/inst/doc/farms.Rnw"
  plot(INIs)  # draws a density plot of I/NI-calls

==> farms_1.4.0.zip: farms/doc/farms.R <==
###################################################
### chunk number 1: 
###################################################
#line 45 "farms.Rnw"
options(width=75)
set.seed(0)
library(farms)
library(utils)
farmsVer<-packageDescription("farms")$Version


###################################################
### chunk number 2: 
###################################################
#line 122 "farms.Rnw"
library(farms)
library(affydata)


###################################################
### chunk number 3: 
###################################################
#line 199 "farms.Rnw"
data(Dilution)
eset<-qFarms(Dilution)  
INIs <- INIcalls(eset)  # apply I/NI calls
summary(INIs)   
I_data <- getI_Eset(INIs) # affybatch containing only  informative probe sets
I_data 


###################################################
### chunk number 4: 
###################################################
#line 210 "farms.Rnw"
  plot(INIs)  # draws a density plot of I/NI-calls


###################################################
### chunk number 5: 
###################################################
#line 221 "farms.Rnw"
eset<-qFarms(Dilution, laplacian=TRUE)  
INIs <- INIcalls(eset)  # apply I/NI calls
summary(INIs)   
I_data <- getI_Eset(INIs) # affybatch containing only  informative probe sets
I_data 


###################################################
### chunk number 6: 
###################################################
#line 231 "farms.Rnw"
  plot(INIs)  # draws a density plot of I/NI-calls
